/* SPDX-License-Identifier: GPL-3.0-or-later */
#include <libknot/packet/pkt.h>

uint32_t packet_ttl(const knot_pkt_t *pkt);
